==> indy-plenum-0.0.1.dev9.tar.gz: indy-plenum-0.0.1.dev9/stp_zmq/simple_zstack.py <==
from plenum.common.metrics_collector import NullMetricsCollector
from stp_zmq.zstack import ZStack
from typing import Dict, Callable
from stp_core.network.auth_mode import AuthMode


class SimpleZStack(ZStack):

    def __init__(self,
                 stackParams: Dict,
                 msgHandler: Callable,
                 seed=None,
                 onlyListener=False,
                 sighex: str=None,
                 config=None,
                 msgRejectHandler=None,
                 create_listener_monitor=False,
                 metrics=NullMetricsCollector(),
                 mt_incoming_size=None,
                 mt_outgoing_size=None):

        # TODO: sighex is unused as of now, remove once test is removed or
        # maybe use sighex to generate all keys, DECISION DEFERRED

        self.stackParams = stackParams
        self.msgHandler = msgHandler

        # TODO: Ignoring `main` param as of now which determines
        # if the stack will have a listener socket or not.
        name = stackParams['name']
        ha = stackParams['ha']
        basedirpath = stackParams['basedirpath']
        queue_size = stackParams['queue_size'] if 'queue_size' in stackParams else 0

        auto = stackParams.pop('auth_mode', None)
        restricted = auto != AuthMode.ALLOW_ANY.value
        super().__init__(name,
                         ha,
                         basedirpath,
                         msgHandler=self.msgHandler,
                         restricted=restricted,
                         seed=seed,
                         onlyListener=onlyListener,
                         config=config,
                         msgRejectHandler=msgRejectHandler,
                         queue_size=queue_size,
                         create_listener_monitor=create_listener_monitor,
                         metrics=metrics,
                         mt_incoming_size=mt_incoming_size,
                         mt_outgoing_size=mt_outgoing_size)

==> indy-plenum-1.13.0.dev1052.tar.gz: indy-plenum-1.13.0.dev1052/stp_zmq/simple_zstack.py <==
from plenum.common.metrics_collector import NullMetricsCollector
from stp_zmq.zstack import ZStack
from typing import Dict, Callable
from stp_core.network.auth_mode import AuthMode


class SimpleZStack(ZStack):

    def __init__(self,
                 stackParams: Dict,
                 msgHandler: Callable,
                 seed=None,
                 onlyListener=False,
                 sighex: str=None,
                 config=None,
                 msgRejectHandler=None,
                 create_listener_monitor=False,
                 metrics=NullMetricsCollector(),
                 mt_incoming_size=None,
                 mt_outgoing_size=None,
                 timer=None):

        # TODO: sighex is unused as of now, remove once test is removed or
        # maybe use sighex to generate all keys, DECISION DEFERRED

        self.stackParams = stackParams
        self.msgHandler = msgHandler

        # TODO: Ignoring `main` param as of now which determines
        # if the stack will have a listener socket or not.
        name = stackParams['name']
        ha = stackParams['ha']
        basedirpath = stackParams['basedirpath']
        queue_size = stackParams['queue_size'] if 'queue_size' in stackParams else 0

        auto = stackParams.pop('auth_mode', None)
        restricted = auto != AuthMode.ALLOW_ANY.value
        super().__init__(name,
                         ha,
                         basedirpath,
                         msgHandler=self.msgHandler,
                         restricted=restricted,
                         seed=seed,
                         onlyListener=onlyListener,
                         config=config,
                         msgRejectHandler=msgRejectHandler,
                         queue_size=queue_size,
                         create_listener_monitor=create_listener_monitor,
                         metrics=metrics,
                         mt_incoming_size=mt_incoming_size,
                         mt_outgoing_size=mt_outgoing_size,
                         timer=timer)
